Struct pixel_game_lib::window::WindowConfig
source · pub struct WindowConfig {
pub buffer_size: Extent2<usize>,
pub scaling: usize,
pub title: String,
pub updates_per_second: u32,
}Expand description
Window configuration.
Fields
buffer_size: Extent2<usize>Amount of pixels for the canvas.
Defaults to (320, 280).
scaling: usizeHow many times the buffer should be scaled to fit the window.
Defaults to 1.
title: StringName in the title bar.
On WASM this will display as a header underneath the rendered content.
Defaults to "Pixel Game".
updates_per_second: u32Updates per second for the update loop.
Defaults to 60.